Hsl class

Constructors

Hsl(double h, double s, double l, [int a = 255])
const
Hsl.fromArgb(Argb c)
factory

Properties

a int
final
h double
final
hashCode int
The hash code for this object.
no setterinherited
l double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
s double
final

Methods

copyWith({double? h, double? s, double? l, int? a}) Hsl
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgb() Argb
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited