DesignPaths class

Architecture → design-system folder (relative to lib/).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

legacyTokenDir(AppArchitecture arch) String
v0.3 token folder. Used for shims and for srik add on old projects.
legacyTokenDirFromId(String architecture) String
systemDir(AppArchitecture arch) String
systemDirFromId(String architecture) String