ArgbPalette class
Constructors
-
ArgbPalette({required Argb primary, required Argb onPrimary, required Argb secondary, required Argb onSecondary, required Argb background, required Argb surface, required Argb surfaceVariant, required Argb surfaceElevated, required Argb surfaceTranslucent, required Argb outline, required Argb outlineVariant, required Argb textPrimary, required Argb textSecondary, required Argb textDisabled, required Argb success, required Argb warning, required Argb error, required Argb info, required Argb shadowLight, required Argb shadowDark, required Argb highlight, required Argb scrim, required List<
Argb> neutrals}) -
const
Properties
- background → Argb
-
final
- error → Argb
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlight → Argb
-
final
- info → Argb
-
final
-
neutrals
→ List<
Argb> -
final
- onPrimary → Argb
-
final
- onSecondary → Argb
-
final
- outline → Argb
-
final
- outlineVariant → Argb
-
final
- primary → Argb
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrim → Argb
-
final
- secondary → Argb
-
final
- shadowDark → Argb
-
final
- shadowLight → Argb
-
final
- success → Argb
-
final
- surface → Argb
-
final
- surfaceElevated → Argb
-
final
- surfaceTranslucent → Argb
-
final
- surfaceVariant → Argb
-
final
- textDisabled → Argb
-
final
- textPrimary → Argb
-
final
- textSecondary → Argb
-
final
- warning → Argb
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited