DesignTokens class

Fully computed token values for one generated project.

Constructors

DesignTokens({required StyleRecipe recipe, required ArgbPalette light, required ArgbPalette dark, required List<double> spacing, required Argb gradientEnd})
const
DesignTokens.fromConfig(ProjectConfig config)
factory

Properties

dark ArgbPalette
final
gradientEnd Argb
final
hashCode int
The hash code for this object.
no setterinherited
light ArgbPalette
final
recipe StyleRecipe
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing List<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited