DesignPalette class

A full color palette. Values are hex strings without the leading #.

Constructors

DesignPalette({required String secondary, required String background, required String surface, required String error, required String success, required String warning, required String info, required String textPrimary, required String textSecondary, required String textDisabled, required String textOnPrimary, required List<String> neutral, required String gradientEnd})
const

Properties

background String
final
error String
final
gradientEnd String
final
hashCode int
The hash code for this object.
no setterinherited
info String
final
neutral List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary String
final
success String
final
surface String
final
textDisabled String
final
textOnPrimary String
final
textPrimary String
final
textSecondary String
final
warning String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

forPreset(DesignPreset preset) DesignPalette