DesignPreset enum
Design system presets — each defines a base color palette.
Values
- material → const DesignPreset
- vibrant → const DesignPreset
- minimal → const DesignPreset
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setter
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String value) → DesignPreset - Parse a user-supplied value. Throws FormatException on unknown input.
-
tryParse(
String value) → DesignPreset? - Tries to parse but returns null on unknown values.
Constants
-
values
→ const List<
DesignPreset> - A constant List of the values in this enum, in order of their declaration.