ProjectConfig class

Full configuration for a project being generated.

Constructors

ProjectConfig({required String projectName, required String description, required String organization, required String outputDirectory, required AppArchitecture architecture, required DesignPreset designPreset, required bool useGradient, required SpacingScale spacingScale, required String brandColor})

Properties

architecture AppArchitecture
final
brandColor String
final
brandColorLiteral String
Brand color as a Dart Color literal argument, e.g. 0xFF6200EE. Accepts #RRGGBB (assumes opaque) or #AARRGGBB (uses given alpha).
no setter
description String
final
designPreset DesignPreset
final
hashCode int
The hash code for this object.
no setterinherited
organization String
final
outputDirectory String
final
projectName String
final
projectPath String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacingScale SpacingScale
final
useGradient bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited