ProjectContext class

Loaded from srik.yaml in an existing project root. Used by srik add commands to know how to generate code.

Constructors

ProjectContext({required String projectName, required String architecture, required String stateManagement, required String routing, required String storage, required String network, required String brandColor, required String designPreset, required bool useGradient, required String spacingScale, required List<String> features, required String projectRoot})

Properties

architecture String
final
brandColor String
final
designPreset String
final
features List<String>
final
hashCode int
The hash code for this object.
no setterinherited
network String
final
projectName String
final
projectRoot String
final
routing String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacingScale String
final
stateManagement String
final
storage String
final
useGradient bool
final

Methods

appendFeature(String featureName) → void
Persist an updated features list back to srik.yaml.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() → void
Rewrite srik.yaml from this context's current state.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

load(String startDir) ProjectContext?
Search up from startDir for a srik.yaml and load it. Returns null if no config is found.