ProjectPrompts class

Constructors

ProjectPrompts()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

collect({required String projectName, String? providedDescription, String? providedOrg, String? providedBrand, String? providedArch, String? providedDesign, bool? providedGradient, String? providedSpacing, required String outputDirectory, bool interactive = true}) ProjectConfig
Collects full project configuration. Uses provided values where given, prompts interactively for the rest.
confirm(String question, {bool defaultValue = true}) bool