FeatureFirstAddTemplates class
Templates for a feature added to a Feature-first project.
Each feature lives in lib/features/<name>/ with these files:
<name>_model.dart, <name>_service.dart, <name>_controller.dart,
<name>_screen.dart
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
controller(
String projectName, String feature) → String -
model(
String projectName, String feature) → String -
screen(
String projectName, String feature, String designDir) → String -
service(
String projectName, String feature) → String -
simpleScreen(
String projectName, String feature, String screen, String designDir) → String - A simple screen added inside an existing feature folder.