SimpleAddTemplates class

Templates for adding a screen (and optional model) to a Simple project. Layout (under lib/): models/

Constructors

SimpleAddTemplates()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

model(String projectName, String name) String
screen(String projectName, String name, String designDir) String