CommonTemplates class
Templates shared across all architectures.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
analysisOptions(
ProjectConfig c) → String -
gitignore(
ProjectConfig c) → String -
pubspec(
ProjectConfig c) → String -
readme(
ProjectConfig c) → String -
srikYaml(
ProjectConfig c) → String