ComponentTemplates class

Reusable style-aware widgets. Source is identical for every visual style; rendering is driven by tokens + AppStyleConfig.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

badge() String
bottomSheet() String
button() String
card() String
chip() String
dialog() String
iconButton() String
surface() String
textField() String