DesignTemplates class

Generates the design system files. These are identical regardless of architecture — only the folder they land in differs.

Constructors

DesignTemplates()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

allFiles(ProjectConfig c) Map<String, String>
Returns map of filename -> contents for the design system.
colors(ProjectConfig c) String
durations(ProjectConfig c) String
gradients(ProjectConfig c) String
Only generated when useGradient is true.
radius(ProjectConfig c) String
spacing(ProjectConfig c) String
textStyles(ProjectConfig c) String
theme(ProjectConfig c) String