TokenTemplates class
Generated token source files (identical API across styles; values differ).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
blur(
DesignTokens tokens) → String -
borders(
DesignTokens tokens) → String -
colors(
ProjectConfig config, DesignTokens tokens) → String -
elevation(
DesignTokens tokens) → String -
gradients(
ProjectConfig config, DesignTokens tokens) → String -
motion(
DesignTokens tokens) → String -
opacity(
DesignTokens tokens) → String -
radius(
DesignTokens tokens) → String -
shadows(
DesignTokens tokens) → String -
sizes(
) → String -
spacing(
ProjectConfig config, DesignTokens tokens) → String -
typography(
DesignTokens tokens) → String