StringUtils class

String case conversion helpers used in template substitution.

Constructors

StringUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isValidPackageName(String input) bool
Checks if a string is a valid Dart package name. Must be lowercase, alphanumeric + underscores, start with letter, not a Dart reserved word.
toCamelCase(String input) String
myApp from my_app.
toPascalCase(String input) String
MyApp from my_app.
toSnakeCase(String input) String
my_app from my_app, MyApp, my-app, or my app.
toTitleCase(String input) String
My App from my_app.