Argb class
Color utilities used by the design-token engine.
Operates on 8-digit ARGB hex strings (no leading #), e.g. FF6200EE.
Constructors
Properties
- a → int
-
final
- b → int
-
final
- dartLiteral → String
-
Dart
Colorliteral argument, e.g.0xFF6200EE.no setter - g → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hex → String
-
no setter
- luminance → double
-
Relative luminance (sRGB), 0–1.
no setter
- opaque → Argb
-
no setter
- r → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withAlpha(
int alpha) → Argb
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited