AppArchitecture enum
Architecture options the CLI can scaffold.
Values
- clean → const AppArchitecture
- mvvm → const AppArchitecture
- featureFirst → const AppArchitecture
- simple → const AppArchitecture
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setter
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String value) → AppArchitecture - Parse a user-supplied value. Throws FormatException on unknown input.
-
tryParse(
String value) → AppArchitecture? - Tries to parse but returns null on unknown values.
Constants
-
values
→ const List<
AppArchitecture> - A constant List of the values in this enum, in order of their declaration.