DesignStyle enum
Canonical generated visual styles.
DesignPreset is a compatibility typedef for this enum.
Values
- material → const DesignStyle
- vibrant → const DesignStyle
- minimalism → const DesignStyle
- neomorphism → const DesignStyle
- skeuomorphism → const DesignStyle
- glassmorphism → const DesignStyle
- claymorphism → const DesignStyle
- maximalism → const DesignStyle
- brutalism → const DesignStyle
- liquidGlass → const DesignStyle
- spatialUi → const DesignStyle
Properties
- dartName → String
-
Generated Dart enum member name (
AppDesignStyle.liquidGlass).no setter - description → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Canonical id persisted in srik.yaml and generated code.
no setter
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String value) → DesignStyle - Parse a user-supplied value. Aliases are normalized. Throws FormatException on unknown input.
-
tryParse(
String value) → DesignStyle? - Tries to parse but returns null on unknown values.